==> arrayfire-3.8.2-4-x86_64.pkg.tar.zst: usr/share/ArrayFire/examples/images/README.md <==
This file provides the necessary redirections to the appropriate license
information for the images under the folder `examples/images` in
[this](https://github.com/arrayfire/assets) repository.

* <a title="By Power3d (Own work) [CC BY-SA 3.0 (http://creativecommons.org/licenses/by-sa/3.0) or GFDL (http://www.gnu.org/copyleft/fdl.html)], via Wikimedia Commons" href="https://commons.wikimedia.org/wiki/File%3ALovely_spider.jpeg"><img width="128" alt="Lovely spider" src="https://upload.wikimedia.org/wikipedia/commons/thumb/b/b3/Lovely_spider.jpeg/512px-Lovely_spider.jpeg"/></a> spider.jpg - This file is licensed under the [Creative Commons](https://en.wikipedia.org/wiki/Creative_Commons) [Attribution-Share Alike 3.0 Unported](https://creativecommons.org/licenses/by-sa/3.0/deed.en) license.
* <a title="By NASA [Public domain], via Wikimedia Commons" href="https://commons.wikimedia.org/wiki/File:ISS_from_Atlantis_-_Sts101-714-016.jpg"><img width="128" alt="ISS from Atlantis - Sts101-714-016" src="https://upload.wikimedia.org/wikipedia/commons/thumb/a/a9/ISS_from_Atlantis_-_Sts101-714-016.jpg/512px-ISS_from_Atlantis_-_Sts101-714-016.jpg"/></a> atlantis.png - This image or video was catalogued by Johnson Space Center of the United States National Aeronautics and Space Administration (NASA) under Photo ID: STS101-714-016. 
* <a title="By http://www.freephotos.lu/ [CC BY 1.0 (http://creativecommons.org/licenses/by/1.0)], via Wikimedia Commons" href="https://commons.wikimedia.org/wiki/File:Image_processing_pre_otsus_algorithm.jpg"><img width="128" alt="Image processing pre otsus algorithm" src="https://upload.wikimedia.org/wikipedia/commons/thumb/4/4b/Image_processing_pre_otsus_algorithm.jpg/512px-Image_processing_pre_otsus_algorithm.jpg"/></a> house.jpg - This file is licensed under the [Creative Commons](https://en.wikipedia.org/wiki/Creative_Commons) [Attribution 1.0 Generic](https://creativecommons.org/licenses/by/1.0/deed.en) license.
* <a title="By RonAlmog, (Flickr page) [CC BY 2.0 (http://creativecommons.org/licenses/by/2.0)], via Wikimedia Commons" href="https://commons.wikimedia.org/wiki/File%3ASunset_Clouds.jpg"><img width="128" alt="Sunset Clouds" src="https://upload.wikimedia.org/wikipedia/commons/thumb/8/8d/Sunset_Clouds.jpg/512px-Sunset_Clouds.jpg"/></a> sunset\_emp.jpg - This file is licensed under the [Creative Commons](https://en.wikipedia.org/wiki/Creative_Commons) [Attribution 2.0 Generic](https://creativecommons.org/licenses/by/2.0/deed.en) license.
* The following images are licensed under public domain (`CC0 1.0 Universal (CC0 1.0) Public Domain Dedication`).
    - <a href="https://commons.wikimedia.org/wiki/File:Rembrandt_-_Portrait_of_an_Old_Man_in_Red_(detail)_-_WGA19183.jpg"><img width="128" alt="Rembrandt - Portrait of an Old Man in Red (detail) - WGA19183" src="https://upload.wikimedia.org/wikipedia/commons/thumb/0/03/Rembrandt_-_Portrait_of_an_Old_Man_in_Red_%28detail%29_-_WGA19183.jpg/256px-Rembrandt_-_Portrait_of_an_Old_Man_in_Red_%28detail%29_-_WGA19183.jpg"/></a> man.jpg
    - <a title="CC0 Public Domain" href="https://pixabay.com/en/grove-of-trees-field-meadow-nature-359532/"><img width="128" src="https://raw.githubusercontent.com/arrayfire/assets/master/examples/images/nature.jpg"/></a> nature.jpg
    - <a title="CC0 Public Domain" href="https://pixabay.com/en/winter-road-black-and-white-84303/"><img width="128" src="https://raw.githubusercontent.com/arrayfire/assets/master/examples/images/trees_ctm.jpg"/></a> trees\_ctm.jpg
    - <a title="CC0 Public Domain" href="https://pixabay.com/en/smoke-colors-wallpaper-662747/"><img width="128" src="https://raw.githubusercontent.com/arrayfire/assets/master/examples/images/fight.jpg"/></a> fight.jpg
    - <a title="Public Domain Image" href="http://www.publicdomainpictures.net/view-image.php?image=15048">Vegetable Woman</a> vegetable-womand.jpg
* <img width="128" src="http://9prady9.github.io/sketches/liz.jpg"/><a rel="license" href="http://creativecommons.org/licenses/by-sa/4.0/"><img alt="Creative Commons License" style="border-width:0" src="https://i.creativecommons.org/l/by-sa/4.0/88x31.png" /></a>This work is licensed under a <a rel="license" href="http://creativecommons.org/licenses/by-sa/4.0/">Creative Commons Attribution-ShareAlike 4.0 International License</a> `arrow.jpg`

* <a title="Brain Scan" href="https://www.nih.gov/news-events/nih-research-matters/brain-scan-may-predict-best-depression-treatment"><img width="128" src="https://www.nih.gov/sites/default/files/styles/floated_media_breakpoint-large/public/news-events/research-matters/2013/20130624-depression.jpg?itok=r5ZwIG-C&timestamp=1431634237"/></a> depression.jpg

==> arrayfire-3.9.0-17-x86_64.pkg.tar.zst: usr/share/ArrayFire/examples/images/README.md <==
This file provides the necessary redirections to the appropriate license
information for the images under the folder `examples/images` in
[this](https://github.com/arrayfire/assets) repository.

* <img width="128" alt="Westerlund 2 space image" src="westerlund.jpg"> Westerlund 2 Image from ASA, ESA, the Hubble Heritage Team (STScI/AURA), A. Nota (ESA/STScI), and the Westerlund 2 Science Team. See
http://www.spacetelescope.org/images/heic1509a/ for details. This file is licensed under the [Creative Commons](https://en.wikipedia.org/wiki/Creative_Commons) [Attribution 4.0 International](https://creativecommons.org/licenses/by/4.0/) license.

* <a title="By Power3d (Own work) [CC BY-SA 3.0 (http://creativecommons.org/licenses/by-sa/3.0) or GFDL (http://www.gnu.org/copyleft/fdl.html)], via Wikimedia Commons" href="https://commons.wikimedia.org/wiki/File%3ALovely_spider.jpeg"><img width="128" alt="Lovely spider" src="https://upload.wikimedia.org/wikipedia/commons/thumb/b/b3/Lovely_spider.jpeg/512px-Lovely_spider.jpeg"/></a> spider.jpg - This file is licensed under the [Creative Commons](https://en.wikipedia.org/wiki/Creative_Commons) [Attribution-Share Alike 3.0 Unported](https://creativecommons.org/licenses/by-sa/3.0/deed.en) license.
* <a title="By NASA [Public domain], via Wikimedia Commons" href="https://commons.wikimedia.org/wiki/File:ISS_from_Atlantis_-_Sts101-714-016.jpg"><img width="128" alt="ISS from Atlantis - Sts101-714-016" src="https://upload.wikimedia.org/wikipedia/commons/thumb/a/a9/ISS_from_Atlantis_-_Sts101-714-016.jpg/512px-ISS_from_Atlantis_-_Sts101-714-016.jpg"/></a> atlantis.png - This image or video was catalogued by Johnson Space Center of the United States National Aeronautics and Space Administration (NASA) under Photo ID: STS101-714-016. 
* <a title="By http://www.freephotos.lu/ [CC BY 1.0 (http://creativecommons.org/licenses/by/1.0)], via Wikimedia Commons" href="https://commons.wikimedia.org/wiki/File:Image_processing_pre_otsus_algorithm.jpg"><img width="128" alt="Image processing pre otsus algorithm" src="https://upload.wikimedia.org/wikipedia/commons/thumb/4/4b/Image_processing_pre_otsus_algorithm.jpg/512px-Image_processing_pre_otsus_algorithm.jpg"/></a> house.jpg - This file is licensed under the [Creative Commons](https://en.wikipedia.org/wiki/Creative_Commons) [Attribution 1.0 Generic](https://creativecommons.org/licenses/by/1.0/deed.en) license.
* <a title="By RonAlmog, (Flickr page) [CC BY 2.0 (http://creativecommons.org/licenses/by/2.0)], via Wikimedia Commons" href="https://commons.wikimedia.org/wiki/File%3ASunset_Clouds.jpg"><img width="128" alt="Sunset Clouds" src="https://upload.wikimedia.org/wikipedia/commons/thumb/8/8d/Sunset_Clouds.jpg/512px-Sunset_Clouds.jpg"/></a> sunset\_emp.jpg - This file is licensed under the [Creative Commons](https://en.wikipedia.org/wiki/Creative_Commons) [Attribution 2.0 Generic](https://creativecommons.org/licenses/by/2.0/deed.en) license.
* The following images are licensed under public domain (`CC0 1.0 Universal (CC0 1.0) Public Domain Dedication`).
    - <a href="https://commons.wikimedia.org/wiki/File:Rembrandt_-_Portrait_of_an_Old_Man_in_Red_(detail)_-_WGA19183.jpg"><img width="128" alt="Rembrandt - Portrait of an Old Man in Red (detail) - WGA19183" src="https://upload.wikimedia.org/wikipedia/commons/thumb/0/03/Rembrandt_-_Portrait_of_an_Old_Man_in_Red_%28detail%29_-_WGA19183.jpg/256px-Rembrandt_-_Portrait_of_an_Old_Man_in_Red_%28detail%29_-_WGA19183.jpg"/></a> man.jpg
    - <a title="CC0 Public Domain" href="https://pixabay.com/en/grove-of-trees-field-meadow-nature-359532/"><img width="128" src="https://raw.githubusercontent.com/arrayfire/assets/master/examples/images/nature.jpg"/></a> nature.jpg
    - <a title="CC0 Public Domain" href="https://pixabay.com/en/winter-road-black-and-white-84303/"><img width="128" src="https://raw.githubusercontent.com/arrayfire/assets/master/examples/images/trees_ctm.jpg"/></a> trees\_ctm.jpg
    - <a title="CC0 Public Domain" href="https://pixabay.com/en/smoke-colors-wallpaper-662747/"><img width="128" src="https://raw.githubusercontent.com/arrayfire/assets/master/examples/images/fight.jpg"/></a> fight.jpg
    - <a title="Public Domain Image" href="http://www.publicdomainpictures.net/view-image.php?image=15048">Vegetable Woman</a> vegetable-womand.jpg
* <img width="128" src="http://9prady9.github.io/sketches/liz.jpg"/><a rel="license" href="http://creativecommons.org/licenses/by-sa/4.0/"><img alt="Creative Commons License" style="border-width:0" src="https://i.creativecommons.org/l/by-sa/4.0/88x31.png" /></a>This work is licensed under a <a rel="license" href="http://creativecommons.org/licenses/by-sa/4.0/">Creative Commons Attribution-ShareAlike 4.0 International License</a> `arrow.jpg`

* <a title="Brain Scan" href="https://www.nih.gov/news-events/nih-research-matters/brain-scan-may-predict-best-depression-treatment"><img width="128" src="https://www.nih.gov/sites/default/files/styles/floated_media_breakpoint-large/public/news-events/research-matters/2013/20130624-depression.jpg?itok=r5ZwIG-C&timestamp=1431634237"/></a> depression.jpg
